---
title: "Helm Template"
---

## helm template

로컬에서 템플릿을 렌더링 한다.

### 개요


차트 템플릿을 로컬에서 렌더링하고 그 결과를 표시한다.

일반적으로 클러스터 내에서 조회되거나 검색되는 모든 값은 로컬에서 즉흥적으로 사용(faked)된다. 
또한 차트 유효성에 대한 서버 측 테스트 (예 : API 지원 여부)가 수행되지는 
않는다.


```
helm template [NAME] [CHART] [flags]
```

### 옵션

```
  -a, --api-versions stringArray     Capabilities.APIVersions에 사용되는 쿠버네티스 API 버전
      --atomic                       설정된 경우, 설치 프로세스는 실패할 경우에 대하여 설치본을 삭제. --atomic 을 사용하면 --wait 플래그도 자동으로 설정
      --ca-file string               이 CA 번들을 사용하여 HTTPS 사용 서버의 인증서를 확인
      --cert-file string             이 SSL 인증서 파일을 사용하여 HTTPS 클라이언트 식별
      --create-namespace             릴리스 네임스페이스가 없는 경우 생성
      --dependency-update            차트를 설치하기 전에 헬름 종속성 업데이트 실행
      --description string           사용자 정의 설명 추가
      --devel                        개발버전으로도 사용 가능. 버전 '>0.0.0.0' 에 해당하며, --version 이 설정되어 있을 경우 무시
      --disable-openapi-validation   설정된 경우, 설치 프로세스는 쿠버네티스 OpenAPI 스키마에 대해 렌더링 된 템플릿의 유효성 검사 미수행
      --dry-run                      모의 설치
  -g, --generate-name                이름 생성 (후에 NAME 매개변수 생략)
  -h, --help                         template 명령어에 대한 도움말
      --include-crds                 템플릿 출력에 CRD 포함 CRD
      --insecure-skip-tls-verify     차트 다운로드를 위한 TLS 인증서 검사 건너뛰기
      --is-upgrade                   Release.IsInstall 대신 .Release.IsUpgrade 를 지정
      --key-file string              이 SSL 키 파일을 사용하여 HTTPS 클라이언트 식별
      --keyring string               검증에 사용되는 공개키의 위치 지정(기본값 "~/.gnupg/pubring.gpg")
      --name-template string         릴리스 이름을 지정 시 사용되는 템플릿 지정
      --no-hooks                     설치 중 훅 실행 방지
      --output-dir string            실행된 템플릿을 표준 출력 대신 지정된 아웃풋 디렉터리의 파일에 작성
      --password string              요청된 차트를 찾을 수 있는 차트 저장소의 비밀번호
      --post-renderer postrenderer   포스트 렌더링에 사용될 실행 파일의 경로. $PATH 에 있으면 바이너리가 사용. 그렇지 않을 경우 주어진 경로에서 실행 파일을 탐색 (기본값 exec)
      --release-name                 아웃풋 디렉터리에 릴리스 이름 사용
      --render-subchart-notes        설정된 경우, 상위차트와 함께 하위차트의 메모를 렌더링
      --replace                      해당 이름이 기록에 남아있는 삭제된 릴리스인 경우에만 주어진 이름을 재사용. 운영 환경에서는 권장되지 않음
      --repo string                  요청된 차트를 찾을 수 있는 차트 저장소 URL
      --set stringArray              명령 줄에서 값 설정(쉼표로 여러 값 또는 개별 값을 지정 가능: 키1=값1,키2=값2)
      --set-file stringArray         명령 줄을 통해 지정된 각 파일에서 값 설정(쉼표로 여러 값 또는 개별 값을 지정 가능: 키1=경로1,키2=경로2)
      --set-string stringArray       명령 줄에서 STRING 값 설정(쉼표로 여러 값 또는 개별 값을 지정 가능: 키1=값1,키2=값2)
  -s, --show-only stringArray        주어진 템플릿에서 렌더링 된 매니페스트만을 표시
      --skip-crds                    설정된 경우, CRD 미설치. 기본적으로 CRD는 아직 없는 경우 설치됨.
      --timeout duration             개별 쿠버네티스 작업(예: 훅에 대한 작업)을 기다리는 시간 (기본값 5m0s)
      --username string              요청 된 차트를 찾을 수 있는 차트 저장소 사용자 이름
      --validate                     현재 가리키는 쿠버네티스 클러스터에 대해 매니페스트의 유효성을 검사. 이는 설치시 수행되는 것과 동일
  -f, --values strings               YAML 파일 또는 URL 에 값 지정 (여러 개를 지정 가능)
      --verify                       사용하기 전에 패키지 확인
      --version string               사용할 정확한 차트 버전 지정. 지정하지 않을 경우 최신 버전 사용
      --wait                         설정된 경우, 릴리스를 성공으로 표시하기 전에 모든 파드, PVC, 서비스, 디플로이먼트, 스테이트풀셋, 레플리카셋의 최소 파드가 Ready 상태가 될때까지 대기. --timeout 만큼 대기
```

### 부모 명령어에서 상속된 옵션들

```
      --debug                       장황한(verbose) 출력 활성화
      --kube-apiserver string       쿠버네티스 API 서버의 주소 및 포트
      --kube-as-group stringArray   작업에 관해 제시할 그룹. 플래그를 여러 번 사용하여 여러 그룹 지정 가능
      --kube-as-user string         작업에 관해 제시할 사용자명
      --kube-context string         사용할 kubeconfig 컨텍스트 이름
      --kube-token string           인증에 사용될 베어러(bearer) 토큰
      --kubeconfig string           kubeconfig 파일 경로
  -n, --namespace string            이 요청에 대한 네임스페이스 스코프
      --registry-config string      레지스트리 구성 파일에 대한 경로 (기본값 "~/.config/helm/registry.json")
      --repository-cache string     캐시된 저장소 색인이 포함된 파일의 경로 (기본값 "~/.cache/helm/repository")
      --repository-config string    저장소 이름 및 URL 을 포함하는 파일 경로 (기본값 "~/.config/helm/repositories.yaml")
```

### 함께 보기

* [helm](../helm)	 - 쿠버네티스에 대한 헬름 패키지 매니저.

###### Auto generated by spf13/cobra on 29-Oct-2020
